@@ -17,6 +17,7 @@ module PostgreSQL.Binary.Decoder
   fn,
   numeric,
   uuid,
+  inet,
   json_ast,
   json_bytes,
   jsonb_ast,
@@ -59,6 +60,7 @@ import qualified PostgreSQL.Binary.Integral as Integral
 import qualified PostgreSQL.Binary.Interval as Interval
 import qualified PostgreSQL.Binary.Numeric as Numeric
 import qualified PostgreSQL.Binary.Time as Time
+import qualified PostgreSQL.Binary.Inet as Inet
 import qualified Data.Vector as Vector
 import qualified Data.ByteString as ByteString
 import qualified Data.ByteString.Lazy as LazyByteString
@@ -68,6 +70,7 @@ import qualified Data.Text.Encoding.Error as Text
 import qualified Data.Text.Lazy.Encoding as LazyText
 import qualified Data.UUID as UUID
 import qualified Data.Aeson as Aeson
+import qualified Network.IP.Addr as IPAddr
 
 
 type Decoder =
@@ -152,6 +155,34 @@ uuid :: Decoder UUID
 uuid =
   UUID.fromWords <$> intOfSize 4 <*> intOfSize 4 <*> intOfSize 4 <*> intOfSize 4
 
+{-# INLINE ip4 #-}
+ip4 :: Decoder IPAddr.IP4
+ip4 =
+  IPAddr.ip4FromOctets <$> intOfSize 1 <*> intOfSize 1 <*> intOfSize 1 <*> intOfSize 1
+
+{-# INLINE ip6 #-}
+ip6 :: Decoder IPAddr.IP6
+ip6 =
+  IPAddr.ip6FromWords <$> intOfSize 2 <*> intOfSize 2 <*> intOfSize 2 <*> intOfSize 2 <*> intOfSize 2 <*> intOfSize 2 <*> intOfSize 2 <*> intOfSize 2
+
+{-# INLINABLE inet #-}
+inet :: Decoder (IPAddr.NetAddr IPAddr.IP)
+inet = do
+  af <- intOfSize 1
+  netmask <- intOfSize 1
+  isCidr <- intOfSize 1
+  ipSize <- intOfSize 1
+  if | af == Inet.inetAddressFamily ->
+       do ip <- ip4
+          return $ inetFromBytes af netmask isCidr ipSize (IPAddr.IPv4 ip)
+     | af == Inet.inet6AddressFamily ->
+       do ip <- ip6
+          return $ inetFromBytes af netmask isCidr ipSize (IPAddr.IPv6 ip)
+     | otherwise -> BinaryParser.failure ("Unknown address family: " <> fromString (show af))
+  where
+    inetFromBytes :: Word8 -> Word8 -> Word8 -> Int8 -> IPAddr.IP -> IPAddr.NetAddr IPAddr.IP
+    inetFromBytes _ netmask _ _ ip = IPAddr.netAddr ip netmask
+
 {-# INLINABLE json_ast #-}
 json_ast :: Decoder Aeson.Value
 json_ast =
